Download CPS technical documentation
Usage
cps_download_docs(
path = cps_docs_dir(),
years = seq(1994, 2024, 2),
overwrite = FALSE
)Arguments
- path
A file path (relative or absolute) where the downloads should go. Defaults to
cps_docs_dir(), which returns~/cps_docsunless overridden viaoptions(cpsvote.docsdir = "your/path").- years
Which years of documentation to download. Defaults to all even-numbered years from 1994 to 2024.
- overwrite
Logical, whether to write over existing files or not. Defaults to FALSE.
Details
File names will be written in the style "cps_nov2024.pdf", with the appropriate years.
The Voting and Registration Supplement is only conducted in even-numbered years (since 1964), so any entry in
yearsoutside of this will be skipped.Currently the package only supports downloads from 1994 onwards, so any entry in
yearsbefore 1994 will be skipped.